<?php
	function cargar_datos ($filename) {
		return unserialize(file_get_contents($filename)); 
	}

	function cargar_plantilla_cas () {
		return file_get_contents('./plantillas/tarifas_esp.htm');
	}

	function cargar_plantilla_eng () {
		return file_get_contents('./plantillas/tarifas_eng.htm');
	}

	function generar_pagina_tarifas_cas ($texto_tarifas_cas, $accion) {
		if ($accion == 'guardar')
			$fichero = fopen('../esp/tarifas_esp.htm', 'w');
		else 
			$fichero = fopen('previsualizar_tarifas_esp.htm', 'w');
			
  		fwrite($fichero, $texto_tarifas_cas);
  		fclose($fichero);
	}

	function generar_pagina_tarifas_eng ($texto_tarifas_eng, $accion) {
		if ($accion == 'guardar')
			$fichero = fopen('../eng/tarifas_eng.htm', 'w');
		else 
			$fichero = fopen('previsualizar_tarifas_eng.htm', 'w');

		fwrite($fichero, $texto_tarifas_eng);
  		fclose($fichero);
	}

	function actualizar_promociones_cas ($promos, $fich_tarifas_cas) {
		$contenido = $fich_tarifas_cas;
		$contenido = str_replace('[TITULO_CAS_0]', $promos[0][TITULO_CAS], $contenido);		
		$contenido = str_replace('[TITULO_CAS_1]', $promos[1][TITULO_CAS], $contenido);		
		$contenido = str_replace('[TITULO_CAS_2]', $promos[2][TITULO_CAS], $contenido);		
		$contenido = str_replace('[TITULO_CAS_3]', $promos[3][TITULO_CAS], $contenido);		
		$contenido = str_replace('[TITULO_CAS_4]', $promos[4][TITULO_CAS], $contenido);		

		$contenido = str_replace('[PRECIO_CAS_0]', $promos[0][PRECIO_CAS], $contenido);		
		$contenido = str_replace('[PRECIO_CAS_1]', $promos[1][PRECIO_CAS], $contenido);		
		$contenido = str_replace('[PRECIO_CAS_2]', $promos[2][PRECIO_CAS], $contenido);		
		$contenido = str_replace('[PRECIO_CAS_3]', $promos[3][PRECIO_CAS], $contenido);		
		$contenido = str_replace('[PRECIO_CAS_4]', $promos[4][PRECIO_CAS], $contenido);		

		$contenido = str_replace('[TEXTO_CAS_0]', $promos[0][TEXTO_CAS], $contenido);		
		$contenido = str_replace('[TEXTO_CAS_1]', $promos[1][TEXTO_CAS], $contenido);		
		$contenido = str_replace('[TEXTO_CAS_2]', $promos[2][TEXTO_CAS], $contenido);		
		$contenido = str_replace('[TEXTO_CAS_3]', $promos[3][TEXTO_CAS], $contenido);		
		$contenido = str_replace('[TEXTO_CAS_4]', $promos[4][TEXTO_CAS], $contenido);		

		return $contenido;
	}

	function actualizar_promociones_eng ($promos, $fich_tarifas_eng) {
		$contenido = $fich_tarifas_eng;
		$contenido = str_replace('[TITULO_ENG_0]', $promos[0][TITULO_ENG], $contenido);		
		$contenido = str_replace('[TITULO_ENG_1]', $promos[1][TITULO_ENG], $contenido);		
		$contenido = str_replace('[TITULO_ENG_2]', $promos[2][TITULO_ENG], $contenido);		
		$contenido = str_replace('[TITULO_ENG_3]', $promos[3][TITULO_ENG], $contenido);		
		$contenido = str_replace('[TITULO_ENG_4]', $promos[4][TITULO_ENG], $contenido);		

		$contenido = str_replace('[PRECIO_ENG_0]', $promos[0][PRECIO_ENG], $contenido);		
		$contenido = str_replace('[PRECIO_ENG_1]', $promos[1][PRECIO_ENG], $contenido);		
		$contenido = str_replace('[PRECIO_ENG_2]', $promos[2][PRECIO_ENG], $contenido);		
		$contenido = str_replace('[PRECIO_ENG_3]', $promos[3][PRECIO_ENG], $contenido);		
		$contenido = str_replace('[PRECIO_ENG_4]', $promos[4][PRECIO_ENG], $contenido);		

		$contenido = str_replace('[TEXTO_ENG_0]', $promos[0][TEXTO_ENG], $contenido);		
		$contenido = str_replace('[TEXTO_ENG_1]', $promos[1][TEXTO_ENG], $contenido);		
		$contenido = str_replace('[TEXTO_ENG_2]', $promos[2][TEXTO_ENG], $contenido);		
		$contenido = str_replace('[TEXTO_ENG_3]', $promos[3][TEXTO_ENG], $contenido);		
		$contenido = str_replace('[TEXTO_ENG_4]', $promos[4][TEXTO_ENG], $contenido);		

		return $contenido;
	}
	
	function actualizar_temporadas_cas ($temporadas, $fich_tarifas_cas) {
		$contenido = $fich_tarifas_cas;
		$contenido = str_replace('[TEMPORADA_BAJA]', $temporadas[BAJA_CAS], $contenido);				
		$contenido = str_replace('[TEMPORADA_MEDIA]', $temporadas[MEDIA_CAS], $contenido);
		$contenido = str_replace('[TEMPORADA_ALTA]', $temporadas[ALTA_CAS], $contenido);
		
		return $contenido;
	}

	function actualizar_temporadas_eng ($temporadas, $fich_tarifas_eng) {
		$contenido = $fich_tarifas_eng;
		$contenido = str_replace('[TEMPORADA_BAJA]', $temporadas[BAJA_ENG], $contenido);				
		$contenido = str_replace('[TEMPORADA_MEDIA]', $temporadas[MEDIA_ENG], $contenido);
		$contenido = str_replace('[TEMPORADA_ALTA]', $temporadas[ALTA_ENG], $contenido);
		
		return $contenido;
	}

	function actualizar_tarifas_generales ($tarifas, $fich_tarifas) { 
		$contenido = $fich_tarifas;
		
		$contenido = str_replace('[TARIFA_BAJA_INDIVIDUAL]', $tarifas[GENERALES][0][INDIVIDUAL], $contenido);				
		$contenido = str_replace('[TARIFA_BAJA_DOBLE]', $tarifas[GENERALES][0][DOBLE], $contenido);				
		$contenido = str_replace('[TARIFA_BAJA_CAMA]', $tarifas[GENERALES][0][CAMA], $contenido);				
		$contenido = str_replace('[TARIFA_BAJA_CUNA]', $tarifas[GENERALES][0][CUNA], $contenido);				
		$contenido = str_replace('[TARIFA_BAJA_MASCOTA]', $tarifas[GENERALES][0][MASCOTA], $contenido);				

		$contenido = str_replace('[TARIFA_MEDIA_INDIVIDUAL]', $tarifas[GENERALES][1][INDIVIDUAL], $contenido);				
		$contenido = str_replace('[TARIFA_MEDIA_DOBLE]', $tarifas[GENERALES][1][DOBLE], $contenido);				
		$contenido = str_replace('[TARIFA_MEDIA_CAMA]', $tarifas[GENERALES][1][CAMA], $contenido);				
		$contenido = str_replace('[TARIFA_MEDIA_CUNA]', $tarifas[GENERALES][1][CUNA], $contenido);				
		$contenido = str_replace('[TARIFA_MEDIA_MASCOTA]', $tarifas[GENERALES][1][MASCOTA], $contenido);				

		$contenido = str_replace('[TARIFA_ALTA_INDIVIDUAL]', $tarifas[GENERALES][2][INDIVIDUAL], $contenido);				
		$contenido = str_replace('[TARIFA_ALTA_DOBLE]', $tarifas[GENERALES][2][DOBLE], $contenido);				
		$contenido = str_replace('[TARIFA_ALTA_CAMA]', $tarifas[GENERALES][2][CAMA], $contenido);				
		$contenido = str_replace('[TARIFA_ALTA_CUNA]', $tarifas[GENERALES][2][CUNA], $contenido);				
		$contenido = str_replace('[TARIFA_ALTA_MASCOTA]', $tarifas[GENERALES][2][MASCOTA], $contenido);				

		return $contenido;		
	}

	function actualizar_tarifas_apartamento ($tarifas, $fich_tarifas) { 
		$contenido = $fich_tarifas;
		
		$contenido = str_replace('[APARTAMENTO_BAJA_NOCHE]', $tarifas[APARTAMENTO][0][NOCHE], $contenido);				
		$contenido = str_replace('[APARTAMENTO_BAJA_CUNA]', $tarifas[APARTAMENTO][0][CUNA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_BAJA_MASCOTA]', $tarifas[APARTAMENTO][0][MASCOTA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_BAJA_FIN_SEMANA]', $tarifas[APARTAMENTO][0][FIN_SEMANA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_BAJA_TEMPORADA]', $tarifas[APARTAMENTO][0][TEMPORADA], $contenido);				

		$contenido = str_replace('[APARTAMENTO_MEDIA_NOCHE]', $tarifas[APARTAMENTO][1][NOCHE], $contenido);				
		$contenido = str_replace('[APARTAMENTO_MEDIA_CUNA]', $tarifas[APARTAMENTO][1][CUNA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_MEDIA_MASCOTA]', $tarifas[APARTAMENTO][1][MASCOTA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_MEDIA_FIN_SEMANA]', $tarifas[APARTAMENTO][1][FIN_SEMANA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_MEDIA_TEMPORADA]', $tarifas[APARTAMENTO][1][TEMPORADA], $contenido);				

		$contenido = str_replace('[APARTAMENTO_ALTA_NOCHE]', $tarifas[APARTAMENTO][2][NOCHE], $contenido);				
		$contenido = str_replace('[APARTAMENTO_ALTA_CUNA]', $tarifas[APARTAMENTO][2][CUNA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_ALTA_MASCOTA]', $tarifas[APARTAMENTO][2][MASCOTA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_ALTA_FIN_SEMANA]', $tarifas[APARTAMENTO][2][FIN_SEMANA], $contenido);				
		$contenido = str_replace('[APARTAMENTO_ALTA_TEMPORADA]', $tarifas[APARTAMENTO][2][TEMPORADA], $contenido);				

		return $contenido;		
	}

	
	function actualizar_tarifas_completo ($tarifas, $fich_tarifas) { 
		$contenido = $fich_tarifas;
		
		$contenido = str_replace('[COMPLETA_BAJA_HOTEL]', $tarifas[COMPLETA][0][HOTEL], $contenido);				
		$contenido = str_replace('[COMPLETA_BAJA_CAMA]', $tarifas[COMPLETA][0][CAMA], $contenido);				
		$contenido = str_replace('[COMPLETA_BAJA_DESAYUNO]', $tarifas[COMPLETA][0][DESAYUNO], $contenido);				
		$contenido = str_replace('[COMPLETA_BAJA_COCINA]', $tarifas[COMPLETA][0][COCINA], $contenido);				
		$contenido = str_replace('[COMPLETA_BAJA_CUNA]', $tarifas[COMPLETA][0][CUNA], $contenido);				
		$contenido = str_replace('[COMPLETA_BAJA_MASCOTA]', $tarifas[COMPLETA][0][MASCOTA], $contenido);				

		$contenido = str_replace('[COMPLETA_MEDIA_HOTEL]', $tarifas[COMPLETA][1][HOTEL], $contenido);				
		$contenido = str_replace('[COMPLETA_MEDIA_CAMA]', $tarifas[COMPLETA][1][CAMA], $contenido);				
		$contenido = str_replace('[COMPLETA_MEDIA_DESAYUNO]', $tarifas[COMPLETA][1][DESAYUNO], $contenido);				
		$contenido = str_replace('[COMPLETA_MEDIA_COCINA]', $tarifas[COMPLETA][1][COCINA], $contenido);				
		$contenido = str_replace('[COMPLETA_MEDIA_CUNA]', $tarifas[COMPLETA][1][CUNA], $contenido);				
		$contenido = str_replace('[COMPLETA_MEDIA_MASCOTA]', $tarifas[COMPLETA][1][MASCOTA], $contenido);				

		$contenido = str_replace('[COMPLETA_ALTA_HOTEL]', $tarifas[COMPLETA][2][HOTEL], $contenido);				
		$contenido = str_replace('[COMPLETA_ALTA_CAMA]', $tarifas[COMPLETA][2][CAMA], $contenido);				
		$contenido = str_replace('[COMPLETA_ALTA_DESAYUNO]', $tarifas[COMPLETA][2][DESAYUNO], $contenido);				
		$contenido = str_replace('[COMPLETA_ALTA_COCINA]', $tarifas[COMPLETA][2][COCINA], $contenido);				
		$contenido = str_replace('[COMPLETA_ALTA_CUNA]', $tarifas[COMPLETA][2][CUNA], $contenido);				
		$contenido = str_replace('[COMPLETA_ALTA_MASCOTA]', $tarifas[COMPLETA][2][MASCOTA], $contenido);				

		return $contenido;
	}

	function actualizar_tarifas ($tarifas, $fich_tarifas) {
		$contenido = actualizar_tarifas_apartamento($tarifas, $fich_tarifas);
		//$contenido = actualizar_tarifas_generales($tarifas, $fich_tarifas);
		return actualizar_tarifas_completo($tarifas, $contenido);
	}
?>