<?php
	include('funciones.php');

	$seccion = $_REQUEST['seccion'];
	$accion=$_REQUEST['accion'];

	$fichero_promociones = "promociones.dat";
	$fichero_temporadas = "temporadas.dat";
	$fichero_tarifas = "tarifas.dat";
	
	if ($seccion == 'promociones') {
		if ($accion == 'guardar')
			$fichero_promociones = "promociones.dat";
		else
			$fichero_promociones = "promociones_previsualizar.dat";
		
		$promo_1 = array(TITULO_CAS => $_REQUEST['titulo1-cas'], 
						 TITULO_ENG => $_REQUEST['titulo1-eng'],
						 PRECIO_CAS => $_REQUEST['precio1-cas'],
						 PRECIO_ENG => $_REQUEST['precio1-eng'],
						 TEXTO_CAS => stripslashes($_REQUEST['texto1-cas']), 
						 TEXTO_ENG => stripslashes($_REQUEST['texto1-eng']));

		$promo_2 = array(TITULO_CAS => $_REQUEST['titulo2-cas'], 
						 TITULO_ENG => $_REQUEST['titulo2-eng'],
						 PRECIO_CAS => $_REQUEST['precio2-cas'],
						 PRECIO_ENG => $_REQUEST['precio2-eng'],
						 TEXTO_CAS => stripslashes($_REQUEST['texto2-cas']), 
						 TEXTO_ENG => stripslashes($_REQUEST['texto2-eng']));

		$promo_3 = array(TITULO_CAS => $_REQUEST['titulo3-cas'], 
						 TITULO_ENG => $_REQUEST['titulo3-eng'],
						 PRECIO_CAS => $_REQUEST['precio3-cas'],
						 PRECIO_ENG => $_REQUEST['precio3-eng'],
						 TEXTO_CAS => stripslashes($_REQUEST['texto3-cas']), 
						 TEXTO_ENG => stripslashes($_REQUEST['texto3-eng']));

		$promo_4 = array(TITULO_CAS => $_REQUEST['titulo4-cas'], 
						 TITULO_ENG => $_REQUEST['titulo4-eng'],
						 PRECIO_CAS => $_REQUEST['precio4-cas'],
						 PRECIO_ENG => $_REQUEST['precio4-eng'],
						 TEXTO_CAS => stripslashes($_REQUEST['texto4-cas']), 
						 TEXTO_ENG => stripslashes($_REQUEST['texto4-eng']));

		$promo_5 = array(TITULO_CAS => $_REQUEST['titulo5-cas'], 
						 TITULO_ENG => $_REQUEST['titulo5-eng'],
						 PRECIO_CAS => $_REQUEST['precio5-cas'],
						 PRECIO_ENG => $_REQUEST['precio5-eng'],
						 TEXTO_CAS => stripslashes($_REQUEST['texto5-cas']), 
						 TEXTO_ENG => stripslashes($_REQUEST['texto5-eng']));

		$promos = array($promo_1, $promo_2, $promo_3, $promo_4, $promo_5);

		// Guardar los datos
		$fp = fopen($fichero_promociones, 'w+') or die("No puedo abrir el fichero ".$fichero_promociones." para guardar.");
		fwrite($fp, serialize($promos));
		fclose($fp);
	}

	if ($seccion == 'tarifas') {
		if ($accion == 'guardar')
			$fichero_temporadas = "temporadas.dat";
		else 
			$fichero_temporadas = "temporadas_previsualizar.dat";
		
		$temporadas = array(BAJA_CAS => $_REQUEST['temp-baja-cas'], 
							BAJA_ENG => $_REQUEST['temp-baja-eng'],
							MEDIA_CAS => $_REQUEST['temp-media-cas'],
							MEDIA_ENG => $_REQUEST['temp-media-eng'],
							ALTA_CAS => $_REQUEST['temp-alta-cas'], 
							ALTA_ENG => $_REQUEST['temp-alta-eng']);
		// Guardar los datos
		$fp = fopen($fichero_temporadas, 'w+') or die("No puedo abrir el fichero ".$fichero_temporadas." para guardar.");
		fwrite($fp, serialize($temporadas));
		fclose($fp);
		
		if ($accion == 'guardar')
			$fichero_tarifas = "tarifas.dat";
		else
			$fichero_tarifas = "tarifas_previsualizar.dat";
			
			
		$tarifas_apartamento_baja = array(NOCHE => $_REQUEST['apartamento-baja-noche'], 
										CUNA => $_REQUEST['apartamento-baja-cuna'],
										MASCOTA => $_REQUEST['apartamento-baja-mascota'],
										FIN_SEMANA => $_REQUEST['apartamento-baja-fin-semana'],
										TEMPORADA => $_REQUEST['apartamento-baja-temporada']);

		$tarifas_apartamento_media = array(NOCHE => $_REQUEST['apartamento-media-noche'], 
										CUNA => $_REQUEST['apartamento-media-cuna'],
										MASCOTA => $_REQUEST['apartamento-media-mascota'],
										FIN_SEMANA => $_REQUEST['apartamento-media-fin-semana'],
										TEMPORADA => $_REQUEST['apartamento-media-temporada']);

		$tarifas_apartamento_alta = array(NOCHE => $_REQUEST['apartamento-alta-noche'], 
										CUNA => $_REQUEST['apartamento-alta-cuna'],
										MASCOTA => $_REQUEST['apartamento-alta-mascota'],
										FIN_SEMANA => $_REQUEST['apartamento-alta-fin-semana'],
										TEMPORADA => $_REQUEST['apartamento-alta-temporada']);
										
												
		/*$tarifas_generales_baja = array(INDIVIDUAL => $_REQUEST['tarifa-baja-individual'], 
										DOBLE => $_REQUEST['tarifa-baja-doble'],
										CAMA => $_REQUEST['tarifa-baja-cama'],
										CUNA => $_REQUEST['tarifa-baja-cuna'],
										MASCOTA => $_REQUEST['tarifa-baja-mascota']);

		$tarifas_generales_media = array(INDIVIDUAL => $_REQUEST['tarifa-media-individual'], 
										DOBLE => $_REQUEST['tarifa-media-doble'],
										CAMA => $_REQUEST['tarifa-media-cama'],
										CUNA => $_REQUEST['tarifa-media-cuna'],
										MASCOTA => $_REQUEST['tarifa-media-mascota']);

		$tarifas_generales_alta = array(INDIVIDUAL => $_REQUEST['tarifa-alta-individual'], 
										DOBLE => $_REQUEST['tarifa-alta-doble'],
										CAMA => $_REQUEST['tarifa-alta-cama'],
										CUNA => $_REQUEST['tarifa-alta-cuna'],
										MASCOTA => $_REQUEST['tarifa-alta-mascota']);
		*/


		$tarifas_completa_baja = array(HOTEL => $_REQUEST['completa-baja-hotel'], 
									   CAMA => $_REQUEST['completa-baja-cama'],
									   DESAYUNO => $_REQUEST['completa-baja-desayuno'],
									   COCINA => $_REQUEST['completa-baja-cocina'],
									   CUNA => $_REQUEST['completa-baja-cuna'],
									   MASCOTA => $_REQUEST['completa-baja-mascota']);

		$tarifas_completa_media = array(HOTEL => $_REQUEST['completa-media-hotel'], 
									   CAMA => $_REQUEST['completa-media-cama'],
									   DESAYUNO => $_REQUEST['completa-media-desayuno'],
									   COCINA => $_REQUEST['completa-media-cocina'],
									   CUNA => $_REQUEST['completa-media-cuna'],
									   MASCOTA => $_REQUEST['completa-media-mascota']);

		$tarifas_completa_alta = array(HOTEL => $_REQUEST['completa-alta-hotel'], 
									   CAMA => $_REQUEST['completa-alta-cama'],
									   DESAYUNO => $_REQUEST['completa-alta-desayuno'],
									   COCINA => $_REQUEST['completa-alta-cocina'],
									   CUNA => $_REQUEST['completa-alta-cuna'],
									   MASCOTA => $_REQUEST['completa-alta-mascota']);


		$tarifas = array(APARTAMENTO => array($tarifas_apartamento_baja, $tarifas_apartamento_media, $tarifas_apartamento_alta),
						/*GENERALES => array($tarifas_generales_baja, $tarifas_generales_media, $tarifas_generales_alta),*/
						 COMPLETA =>  array($tarifas_completa_baja, $tarifas_completa_media, $tarifas_completa_alta));

		// Guardar los datos
		$fp = fopen($fichero_tarifas, 'w+') or die("No puedo abrir el fichero ".$fichero_tarifas." para guardar.");
		fwrite($fp, serialize($tarifas));
		fclose($fp);
		
	}

	$plantilla_cas = cargar_plantilla_cas();
	$plantilla_eng = cargar_plantilla_eng();

	$promos = cargar_datos($fichero_promociones);
	$plantilla_cas = actualizar_promociones_cas($promos, $plantilla_cas);
	$plantilla_eng = actualizar_promociones_eng($promos, $plantilla_eng);

	$temporadas = cargar_datos($fichero_temporadas);
	$plantilla_cas = actualizar_temporadas_cas($temporadas, $plantilla_cas);
	$plantilla_eng = actualizar_temporadas_eng($temporadas, $plantilla_eng);
	
	$tarifas = cargar_datos($fichero_tarifas);
	$plantilla_cas = actualizar_tarifas($tarifas, $plantilla_cas);
	$plantilla_eng = actualizar_tarifas($tarifas, $plantilla_eng);
	
	generar_pagina_tarifas_cas($plantilla_cas, $accion);
	generar_pagina_tarifas_eng($plantilla_eng, $accion);
	
	if ($accion == 'guardar') {
		print "<script>alert('Cambios guardados')</script>";
		print("<script>window.location.replace('index.htm');</script>"); 		
	}
	else {
		if ($accion == 'previsualizar_castellano')
			header('Location: previsualizar_tarifas_esp.htm');
		else
			header('Location: previsualizar_tarifas_eng.htm');
	}
?>
